@@ -283,38 +283,6 @@ If the system call failed, an exception will be thrown with the error code set t
 
 The same as L</"getsockopt">, but the option value can be specifed by the C<int> type.
 
-=head2 ioctlsocket
-
-  static method ioctlsocket : int ($s : int, $cmd : int, $argp : int*);
-
-The ioctlsocket function controls the I/O mode of a socket.
-
-See the detail of the L<ioctlsocket|https://docs.microsoft.com/en-us/windows/win32/api/winsock/nf-winsock-ioctlsocket> function in the case of Windows.
-
-If the system call failed, an exception will be thrown with the error code set to the class id of the L<Error::System> class.
-
-=head2 closesocket
-
-  static method closesocket : int ($s : int);
-
-The closesocket function closes an existing socket.
-
-See the detail of the L<closesocket|https://docs.microsoft.com/en-us/windows/win32/api/winsock/nf-winsock-closesocket> function in the case of Windows.
-
-If the system call failed, an exception will be thrown with the error code set to the class id of the L<Error::System> class.
-
-=head2 WSAPoll
-
-  static method WSAPoll : int ($fds : Sys::IO::PollfdArray, $nfds : int, $timeout : int);
-
-The WSAPoll function determines status of one or more sockets.
-
-See the detail of the L<WSAPoll|https://docs.microsoft.com/en-us/windows/win32/api/winsock2/nf-winsock2-wsapoll> function in the case of Windows.
-
-The file descriptors(fds) is a L<Sys::IO::PollfdArray> object.
-
-If the system call failed, an exception will be thrown with the error code set to the class id of the L<Error::System> class.
-
 =head2 getaddrinfo_raw
 
   static method getaddrinfo_raw : int ($node : string, $service : string,
@@ -373,20 +341,6 @@ The gai_strerror() function translates these error codes to a human readable str
 
 See the detail of the L<getnameinfo|https://linux.die.net/man/3/gai_strerror> function in the case of Linux.
 
-=head2 ioctl_int
-
-  static method ioctl_int : int ($fd : int, $request : int, $request_arg_ref : int*);
-
-The same as L<ioctl_int in Sys::IO|SPVM::Sys::IO/"ioctl_int">, but portable in socket.
-
-=head2 poll
-
-  static method poll : int ($fds : Sys::IO::PollfdArray, $nfds : int, $timeout : int);
-
-The same as L<poll in Sys::IO|SPVM::Sys::IO/"poll">, but portable in socket.
-
-The file descriptors(fds) is a L<Sys::IO::PollfdArray> object.
-
 =head2 close
 
   static method close : int ($fd : int);
