@@ -3,13 +3,15 @@
 #include <assert.h>
 
 #ifdef _WIN32
-# include <ws2tcpip.h>
-# include <winsock2.h>
-# include <io.h>
+  #include <ws2tcpip.h>
+  #include <winsock2.h>
+  #include <io.h>
 #else
-#include <sys/types.h>
-#include <sys/socket.h>
-#include <netdb.h>
+  #include <sys/types.h>
+  #include <sys/socket.h>
+  #include <netinet/in.h>
+  #include <netinet/ip.h>
+  #include <netdb.h>
 #endif
 
 static const char* FILE_NAME = "Sys/Socket/Addrinfo.c";
